@@ -5,7 +5,7 @@ package Mojolicious::Plugin::Prove;
 use Mojo::Base 'Mojolicious::Plugin::Prove::Base';
 use Mojo::File;
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -46,11 +46,11 @@ sub register {
             conf      => $self->conf,
         );
         
-        $pr->get('/')->to( '#list' );
-        $pr->get('/test/*name/file/*file/run')->to( '#run' );
-        $pr->get('/test/*name/file/*file')->to( '#file' );
-        $pr->get('/test/*name/run')->to( '#run' );
-        $pr->get('/test/*name')->to( '#list' );
+        $pr->get('/')->to( '#list' )->name('mpp_prove_list');
+        $pr->get('/test/*name/file/*file/run')->to( '#run' )->name('mpp_run_file');
+        $pr->get('/test/*name/file/*file')->to( '#file' )->name('mpp_file');
+        $pr->get('/test/*name/run')->to( '#run' )->name('mpp_run_all');
+        $pr->get('/test/*name')->to( '#list' )->name('mpp_file_list');
     }
 }
 
@@ -68,7 +68,7 @@ Mojolicious::Plugin::Prove - run test scripts via browser
 
 =head1 VERSION
 
-version 0.09
+version 0.1
 
 =head1 SYNOPSIS
 
