@@ -1,10 +1,12 @@
 package Mojolicious::Plugin::Prove::Base;
 
+# ABSTRACT: Base class for Mojolicious::Plugin::Prove
+
 use Mojo::Base 'Mojolicious::Plugin';
 
 use Cwd 'abs_path';
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 has 'prefix';
 has 'conf';
@@ -31,11 +33,11 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::Prove::Base
+Mojolicious::Plugin::Prove::Base - Base class for Mojolicious::Plugin::Prove
 
 =head1 VERSION
 
-version 0.09
+version 0.1
 
 =head1 METHODS
 
