@@ -1,5 +1,7 @@
 package Mojolicious::Plugin::Prove::Controller;
 
+# ABSTRACT: Controller for Mojolicious::Plugin::Prove
+
 use Mojo::Base 'Mojolicious::Controller';
 
 use App::Prove;
@@ -7,7 +9,7 @@ use Capture::Tiny qw(capture);
 use File::Basename;
 use File::Find::Rule;
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 sub list {
     my $self = shift;
@@ -95,13 +97,26 @@ sub run {
 
     local $ENV{HARNESS_TIMER};
 
+    my $accepts = $self->app->renderer->accepts( $self )->[0] // 'html';
+    my $format  = $accepts =~ m{\Ahtml?} ? 'html' : $accepts;
+
     my $prove = App::Prove->new;
+
     $prove->process_args( '--norc', @args );
+    $prove->formatter('TAP::Formatter::HTML') if $format eq 'html';
+
     my ($stdout, $stderr, @result) = capture {
         $prove->run;
     };
     
-    $self->render( text => $stdout );
+    if ( $format eq 'html' ) {
+        $stdout =~ s{\A.*?^(<!DOCTYPE)}{$1}xms;
+        $self->render( text => $stdout );
+    }
+    else {
+        $self->tx->res->headers->content_type('text/plain');
+        $self->render( text => $stdout );
+    }
 }
 
 1;
@@ -114,11 +129,11 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::Prove::Controller
+Mojolicious::Plugin::Prove::Controller - Controller for Mojolicious::Plugin::Prove
 
 =head1 VERSION
 
-version 0.09
+version 0.1
 
 =head1 METHODS
 
